@@ -52,10 +52,9 @@ public:
     std::string friendlyName;
     std::string manufacturer;
     std::string modelName;
-    Upnp_SID    SID{0}; /* Subscription Id */
+    Upnp_SID    SID; /* Subscription Id */
 
-    void initFromDeviceAndService(const UPnPDeviceDesc& devdesc,
-                                  const UPnPServiceDesc& servdesc) {
+    void initFromDeviceAndService(const UPnPDeviceDesc& devdesc, const UPnPServiceDesc& servdesc) {
         actionURL = caturl(devdesc.URLBase, servdesc.controlURL);
         eventURL = caturl(devdesc.URLBase, servdesc.eventSubURL);
         serviceType = servdesc.serviceType;
@@ -81,17 +80,12 @@ static std::mutex cblock;
 
 
 Service::Service(const UPnPDeviceDesc& devdesc, const UPnPServiceDesc& servdesc)
+    : m(new Internal())
 {
-    if ((m = new Internal()) == 0) {
-        LOGERR("Device::Device: out of memory" << endl);
-        return;
-    }
-
     m->initFromDeviceAndService(devdesc, servdesc);
     // Only does anything the first time
     initEvents();
-    // serviceInit() will be called from the derived class constructor
-    // if needed
+    // serviceInit() will be called from the derived class constructor if needed
 }
 
 bool Service::initFromDescription(const UPnPDeviceDesc& devdesc)
@@ -112,11 +106,8 @@ bool Service::initFromDescription(const UPnPDeviceDesc& devdesc)
 }
 
 Service::Service()
+    : m(new Internal())
 {
-    if ((m = new Internal()) == 0) {
-        LOGERR("Device::Device: out of memory" << endl);
-        return;
-    }
 }
 
 Service::~Service()
@@ -124,7 +115,7 @@ Service::~Service()
     LOGDEB1("Service::~Service: " << m->eventURL << " SID " << m->SID << endl);
     unregisterCallback();
     delete m;
-    m = 0;
+    m = nullptr;
 }
 
 const string& Service::getFriendlyName() const
@@ -166,23 +157,19 @@ int Service::runAction(const SoapOutgoing& args, SoapIncoming& data)
     }
     UpnpClient_Handle hdl = lib->m->getclh();
 
-    LOGDEB1("Service::runAction: url [" << m->actionURL <<
-            " serviceType " << m->serviceType <<
-            " rqst: [" << "TBD SOME REQUEST" << "]" << endl);
-
     std::vector<std::pair<std::string, std::string>> response;
     int errcode;
     std::string errdesc;
     int ret =  UpnpSendAction(hdl, "", m->actionURL, m->serviceType,
-                              args.m->name, args.m->data, response, &errcode,
-                              errdesc);
+                              args.m->name, args.m->data, response, &errcode, errdesc);
     if (ret != UPNP_E_SUCCESS) {
-        LOGINF("Service::runAction: UpnpSendAction returned " << ret << endl);
+        LOGINF("Service::runAction: UpnpSendAction error " << ret << " for service: " <<
+               args.m->serviceType << " action: " << args.m->name << " args: " <<
+               SoapHelp::argsToStr(args.m->data.begin(), args.m->data.end()) << "\n");
         if (ret < 0) {
             LOGINF("    error message: " << UpnpGetErrorMessage(ret) << endl);
         } else {
-            LOGINF("    Response errorCode: " << errcode <<
-                   " errorDescription: " << errdesc << endl);
+            LOGINF("    Response errorCode: " << errcode << " errorDescription: " << errdesc<<"\n");
         }
         return ret;
     }
@@ -197,9 +184,8 @@ int Service::runTrivialAction(const std::string& actionName)
     return runAction(args, data);
 }
 
-template <class T> int Service::runSimpleGet(const std::string& actnm,
-                                             const std::string& valnm,
-                                             T *valuep)
+template <class T> int Service::runSimpleGet(
+    const std::string& actnm, const std::string& valnm, T *valuep)
 {
     SoapOutgoing args(m->serviceType, actnm);
     SoapIncoming data;
@@ -208,16 +194,14 @@ template <class T> int Service::runSimpleGet(const std::string& actnm,
         return ret;
     }
     if (!data.get(valnm.c_str(), valuep)) {
-        LOGERR("Service::runSimpleAction: " << actnm <<
-               " missing " << valnm << " in response" << std::endl);
+        LOGERR("Service::runSimpleAction: " << actnm << " missing " << valnm <<" in response"<<"\n");
         return UPNP_E_BAD_RESPONSE;
     }
     return 0;
 }
 
-template <class T> int Service::runSimpleAction(const std::string& actnm,
-                                                const std::string& valnm,
-                                                T value)
+template <class T> int Service::runSimpleAction(
+    const std::string& actnm, const std::string& valnm, T value)
 {
     SoapOutgoing args(m->serviceType, actnm);
     args(valnm, SoapHelp::val2s(value));
@@ -230,12 +214,15 @@ static int srvCB(Upnp_EventType et, CBCONST void* vevp, void*)
 {
     std::unique_lock<std::mutex> lock(cblock);
 
-    // All event types begin with a SID field
+    // All event types have a SID field
     const char *sid = UpnpEvent_get_SID_cstr((UpnpEvent*)vevp);
     
     LOGDEB0("Service:srvCB: " << evTypeAsString(et) << " SID " << sid << endl);
 
     auto it = o_calls.find(sid);
+    if (it == o_calls.end()) {
+        LOGINF("Service::srvCB: no callback found for SID " << sid << "\n");
+    }
 
     switch (et) {
     case UPNP_EVENT_AUTORENEWAL_FAILED:
@@ -248,23 +235,19 @@ static int srvCB(Upnp_EventType et, CBCONST void* vevp, void*)
     case UPNP_EVENT_RECEIVED:
     {
         UpnpEvent *evp = (UpnpEvent *)vevp;
-        LOGDEB1("Service:srvCB: var change event: SID " << sid <<
-                " EventKey " << UpnpEvent_get_EventKey(evp) << " changed " <<
-                SoapHelp::argsToString(evp->ChangedVariables.begin(),
-                                       evp->ChangedVariables.end()) << "\n");
+        LOGDEB1("Service:srvCB: var change event: SID " << sid << " EventKey " <<
+                UpnpEvent_get_EventKey(evp) << " changed " <<
+                SoapHelp::argsToStr(evp->ChangedVariables.begin(),
+                                    evp->ChangedVariables.end()) << "\n");
 
         if (it != o_calls.end()) {
             (it->second)(evp->ChangedVariables);
-        } else {
-            LOGINF("Service::srvCB: no callback found for SID " << sid << "\n");
         }
         break;
     }
 
     default:
-        // Ignore other events for now
-        LOGDEB("Service:srvCB: unprocessed evt type: [" <<
-               evTypeAsString(et) << "]"  << "\n");
+        LOGDEB("Service:srvCB: unprocessed evt type: [" << evTypeAsString(et) << "]"  << "\n");
         break;
     }
 
@@ -303,14 +286,13 @@ bool Service::Internal::subscribe()
         return false;
     }
     int timeout = lib->m->getSubsTimeout();
-    int ret = UpnpSubscribe(lib->m->getclh(), eventURL.c_str(),
-                            &timeout, SID);
+    int ret = UpnpSubscribe(lib->m->getclh(), eventURL.c_str(), &timeout, SID);
     if (ret != UPNP_E_SUCCESS) {
-        LOGERR("Service:subscribe: failed: " << ret << " : " <<
+        LOGERR("Service:subscribe: " << eventURL << " failed: " << ret << " : " <<
                UpnpGetErrorMessage(ret) << endl);
         return false;
     }
-    LOGDEB1("Service::subs:   " << eventURL << " SID " << SID << endl);
+    LOGDEB("Service::subscribe:   " << eventURL << " SID " << SID << endl);
     return true;
 }
 
@@ -322,11 +304,11 @@ bool Service::Internal::unSubscribe()
         LOGINF("Service::unSubscribe: no lib" << endl);
         return false;
     }
-    if (SID[0]) {
+    if (!SID.empty()) {
         int ret = UpnpUnSubscribe(lib->m->getclh(), SID);
         if (ret != UPNP_E_SUCCESS) {
             LOGERR("Service:unSubscribe: failed: " << ret << " : " <<
-                   UpnpGetErrorMessage(ret) << endl);
+                   UpnpGetErrorMessage(ret) << " for SID [" << SID << "]\n");
             return false;
         }
         // Let the caller erase m->SID[] because there may be other
@@ -342,21 +324,19 @@ bool Service::registerCallback(evtCBFunc c)
         return false;
     }
     std::unique_lock<std::mutex> lock(cblock);
-    LOGDEB1("Service::registerCallback: " << m->eventURL << " SID " <<
-            m->SID << endl);
+    LOGDEB1("Service::registerCallback: " << m->eventURL << " SID " << m->SID << endl);
     o_calls[m->SID] = c;
     return true;
 }
 
 void Service::unregisterCallback()
 {
-    LOGDEB1("Service::unregisterCallback: " << m->eventURL << " SID " <<
-            m->SID << endl);
-    if (m->SID[0]) {
+    LOGDEB1("Service::unregisterCallback: " << m->eventURL << " SID " << m->SID << endl);
+    if (!m->SID.empty()) {
         m->unSubscribe();
         std::unique_lock<std::mutex> lock(cblock);
         o_calls.erase(m->SID);
-        m->SID[0] = 0;
+        m->SID.clear();
     }
 }
 
@@ -380,7 +360,7 @@ void Service::installReporter(VarEventReporter* reporter)
 bool Service::reSubscribe()
 {
     LOGDEB("Service::reSubscribe()\n");
-    if (m->SID[0] == 0) {
+    if (m->SID.empty()) {
         LOGINF("Service::reSubscribe: no subscription (null SID)\n");
         return false;
     }
@@ -389,8 +369,7 @@ bool Service::reSubscribe()
         std::unique_lock<std::mutex> lock(cblock);
         auto it = o_calls.find(m->SID);
         if (it == o_calls.end()) {
-            LOGINF("Service::reSubscribe: no callback found for m->SID " <<
-                   m->SID << endl);
+            LOGINF("Service::reSubscribe: no callback found for m->SID " << m->SID << endl);
             return false;
         }
         c = it->second;
@@ -401,8 +380,7 @@ bool Service::reSubscribe()
 }
 
 template int Service::runSimpleAction<int>(string const&, string const&, int);
-template int Service::runSimpleAction<string>(string const&, string const&,
-                                              string);
+template int Service::runSimpleAction<string>(string const&, string const&, string);
 template int Service::runSimpleGet<int>(string const&, string const&, int*);
 template int Service::runSimpleGet<bool>(string const&, string const&, bool*);
 template int Service::runSimpleAction<bool>(string const&, string const&, bool);
